/**
* @license Apache-2.0
*
* Copyright (c) 2020 The Stdlib Authors.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*    http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

#include "stdlib/blas/base/dscal.h"
#include "stdlib/blas/base/shared.h"

/**
* Multiplies a double-precision floating-point vector `X` by a constant.
*
* @param N       number of indexed elements
* @param alpha   scalar
* @param X       input array
* @param stride  index increment
*/
void API_SUFFIX(c_dscal)( const CBLAS_INT N, const double alpha, double *X, const CBLAS_INT stride ) {
	CBLAS_INT m;
	CBLAS_INT i;

	if ( N <= 0 || stride <= 0 || alpha == 1.0 ) {
		return;
	}
	// Use loop unrolling if the stride is equal to `1`...
	if ( stride == 1 ) {
		m = N % 5;

		// If we have a remainder, run a clean-up loop...
		if ( m > 0 ) {
			for ( i = 0; i < m; i++ ) {
				X[ i ] *= alpha;
			}
		}
		if ( N < 5 ) {
			return;
		}
		for ( i = m; i < N; i += 5 ) {
			X[ i ] *= alpha;
			X[ i+1 ] *= alpha;
			X[ i+2 ] *= alpha;
			X[ i+3 ] *= alpha;
			X[ i+4 ] *= alpha;
		}
		return;
	}
	for ( i = 0; i < N*stride; i += stride ) {
		X[ i ] *= alpha;
	}
	return;
}
